==> kdevplatform-1.5.80.tar.xz: kdevplatform-1.5.80/plugins/filemanager/kdevfilemanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=system-file-manager
Exec=blubb
Comment=This plugin brings a filemanager to KDevelop.
Comment[bg]=Тaзи приставка вгражда файловия манипулатор към KDevelop.
Comment[bs]=Dodatak donosi menadžer datoteka KDevelopu.
Comment[ca]=Aquest connector proporciona un gestor de fitxers a KDevelop.
Comment[ca@valencia]=Este connector proporciona un gestor de fitxers a KDevelop.
Comment[da]=Dette plugin bringer filhåndtering til KDevelop.
Comment[de]=Dieses Modul integriert einen Datei-Browser in KDevelop.
Comment[el]=Αυτό το πρόσθετο ενσωματώνει ένα διαχειριστή αρχείων στο KDevelop
Comment[en_GB]=This plugin brings a filemanager to KDevelop.
Comment[es]=Este complemento proporciona un gestor de archivos a KDevelop.
Comment[et]=See plugin võimaldab kasutada KDevelopis failihaldurit.
Comment[fi]=Tämä liitännäinen tuo tiedostohallinnan KDevelopiin.
Comment[fr]=Ce module externe offre un gestionnaire de fichiers pour KDevelop.
Comment[gl]=Este complemento incorpora un xestor de ficheiros no KDevelop.
Comment[hu]=Ez a bővítmény egy fájlkezelőt hoz a KDesktophoz.
Comment[it]=Questa estensione porta un gestore di file in KDevelop.
Comment[ja]=このプラグインはファイルマネージャを KDevelop に統合します
Comment[kk]=Бұл плагині KDevelop-қа файл менеджер мүмкіндіктерін әкеледі.
Comment[lv]=Šis spraudnis nodrošina failu pārvaldnieka funkcionalitāti iekš KDevelop.
Comment[nb]=Dette programtillegget tar inn en filbehandler i KDevelop.
Comment[nds]=Dit Moduul stellt en Dateipleger för KDevelop praat.
Comment[nl]=Deze plugin brengt een bestandsbeheerder in KDevelop.
Comment[pl]=Ta wtyczka udostępnia menadżer plików w KDevelopie.
Comment[pt]=Este 'plugin' oferece um gestor de ficheiros para o KDevelop.
Comment[pt_BR]=Este plugin provê um gerenciador de arquivos ao KDevelop.
Comment[ru]=Это расширение добавляет в KDevelop диспетчер файлов.
Comment[sk]=Tento plugin prináša správcu súborov do KDevelop.
Comment[sl]=Vstavek v KDevelop prinese upravljalnik datotek.
Comment[sv]=Insticksprogrammet ger KDevelop en filhanterare.
Comment[tr]=Bu eklenti KDevelop için bir dosya yönetici sağlar.
Comment[ug]=بۇ قىستۇرما ھۆججەت باشقۇرغۇنى KDevelop نىڭ ئىچىگە ئېلىپ كىرىدۇ
Comment[uk]=За допомогою цього додатка можна отримати доступ до менеджера файлів у KDevelop.
Comment[x-test]=xxThis plugin brings a filemanager to KDevelop.xx
Comment[zh_CN]=此插件对 KDevelop 整合一个文件管理器。
Comment[zh_TW]=此外掛程式讓 KDevelop 可使用檔案管理員。
Name=KDE File Manager Integration
Name[bg]=Интегриране на файлов манипулатор на KDE
Name[bs]=KDe menadžer integracije datoteke
Name[ca]=Integració del gestor de fitxers del KDE
Name[ca@valencia]=Integració del gestor de fitxers del KDE
Name[da]=Integration af KDE filhåndtering
Name[de]=Integration der KDE-Dateiverwaltung
Name[el]=Ενσωμάτωση διαχειριστή αρχείων του KDE
Name[en_GB]=KDE File Manager Integration
Name[es]=Integración del gestor de archivos de KDE
Name[et]=KDE lõimimine failihalduriga
Name[fi]=KDE-tiedostohallintaintegrointi
Name[fr]=Intégration du gestionnaire de fichiers de KDE
Name[gl]=Integración co xestor de ficheiros do KDE
Name[hu]=KDE fájlkezelő integráció
Name[it]=Integrazione gestore di file di KDE
Name[ja]=KDE のファイルマネージャの統合
Name[kk]=KDE файл менеджерімен біріктіру
Name[nb]=Integrasjon med KDE filbehandler
Name[nds]=KDE-Dateiplegerünnerstütten
Name[nl]=KDE Bestandsbeheerder-integratie
Name[pl]=Integracja menadżera plików KDE
Name[pt]=Integração com o Gestor de Ficheiros do KDE
Name[pt_BR]=Integração com o gerenciador de arquivos do KDE
Name[ru]=Интеграция файлового менеджера KDE
Name[sk]=Integrácia správcu súborov KDE
Name[sl]=Vgradnja KDE-jevega upravljalnika datotek
Name[sv]=Integrering med KDE:s filhanterare
Name[tr]=KDE Dosya Yöneticisi Bütünleşmesi
Name[ug]=KDE ھۆججەت باشقۇرغۇنىڭ يۈرۈشلەشتۈرۈلۇشى
Name[uk]=Інтеграція засобу керування файлами KDE
Name[x-test]=xxKDE File Manager Integrationxx
Name[zh_CN]=KDE 文件管理器整合
Name[zh_TW]=KDE 檔案管理員整合
GenericName=File Manager
GenericName[bg]=Файлов манипулатор
GenericName[bs]=Upravljanje datotekama
GenericName[ca]=Gestor de fitxers
GenericName[ca@valencia]=Gestor de fitxers
GenericName[cs]=Správce souborů
GenericName[da]=Filhåndtering
GenericName[de]=Dateiverwaltung
GenericName[el]=Διαχειριστής αρχείων
GenericName[en_GB]=File Manager
GenericName[eo]=Dosieradministrilo
GenericName[es]=Gestor de archivos
GenericName[et]=Failihaldur
GenericName[fi]=Tiedostohallinta
GenericName[fr]=Gestionnaire de fichiers
GenericName[ga]=Bainisteoir Comhad
GenericName[gl]=Xestor de ficheiros
GenericName[hu]=Fájlkezelő
GenericName[it]=Gestore di file
GenericName[ja]=ファイルマネージャ
GenericName[kk]=Файл менеджері
GenericName[lt]=Failų tvarkyklė
GenericName[lv]=Failu pārvaldnieks
GenericName[mr]=फाईल व्यवस्थापक
GenericName[ms]=Pengurus Fail
GenericName[nb]=Filbehandler
GenericName[nds]=Dateipleger
GenericName[nl]=Bestandsbeheerder
GenericName[pa]=ਫਾਇਲ ਮੈਨੇਜਰ
GenericName[pl]=Menadżer plików
GenericName[pt]=Gestor de Ficheiros
GenericName[pt_BR]=Gerenciador de arquivos
GenericName[ro]=Gestionar de fișiere
GenericName[ru]=Файловый менеджер
GenericName[sk]=Správca súborov
GenericName[sl]=Upravljalnik datotek
GenericName[sv]=Filhanterare
GenericName[tr]=Dosya Yönetici
GenericName[ug]=ھۆججەت باشقۇرغۇ
GenericName[uk]=Менеджер файлів
GenericName[x-test]=xxFile Managerxx
GenericName[zh_CN]=文件管理器
GenericName[zh_TW]=檔案管理員
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevfilemanager
X-KDE-PluginInfo-Name=kdevfilemanager
X-KDE-PluginInfo-Author=Alexander Dymo
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevplatform-1.5.90.tar.xz: kdevplatform-1.5.90/plugins/filemanager/kdevfilemanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=system-file-manager
Exec=blubb
Comment=This plugin brings a filemanager to KDevelop.
Comment[bg]=Тaзи приставка вгражда файловия манипулатор към KDevelop.
Comment[bs]=Dodatak donosi menadžer datoteka KDevelopu.
Comment[ca]=Aquest connector proporciona un gestor de fitxers al KDevelop.
Comment[ca@valencia]=Este connector proporciona un gestor de fitxers a KDevelop.
Comment[da]=Dette plugin bringer filhåndtering til KDevelop.
Comment[de]=Dieses Modul integriert einen Datei-Browser in KDevelop.
Comment[el]=Αυτό το πρόσθετο ενσωματώνει ένα διαχειριστή αρχείων στο KDevelop
Comment[en_GB]=This plugin brings a filemanager to KDevelop.
Comment[es]=Este complemento proporciona un gestor de archivos a KDevelop.
Comment[et]=See plugin võimaldab kasutada KDevelopis failihaldurit.
Comment[fi]=Tämä liitännäinen tuo tiedostohallinnan KDevelopiin.
Comment[fr]=Ce module externe offre un gestionnaire de fichiers pour KDevelop.
Comment[gl]=Este complemento incorpora un xestor de ficheiros no KDevelop.
Comment[hu]=Ez a bővítmény egy fájlkezelőt hoz a KDesktophoz.
Comment[it]=Questa estensione porta un gestore di file in KDevelop.
Comment[ja]=このプラグインはファイルマネージャを KDevelop に統合します
Comment[kk]=Бұл плагині KDevelop-қа файл менеджер мүмкіндіктерін әкеледі.
Comment[lv]=Šis spraudnis nodrošina failu pārvaldnieka funkcionalitāti iekš KDevelop.
Comment[nb]=Dette programtillegget tar inn en filbehandler i KDevelop.
Comment[nds]=Dit Moduul stellt en Dateipleger för KDevelop praat.
Comment[nl]=Deze plugin brengt een bestandsbeheerder in KDevelop.
Comment[pl]=Ta wtyczka udostępnia menadżer plików w KDevelopie.
Comment[pt]=Este 'plugin' oferece um gestor de ficheiros para o KDevelop.
Comment[pt_BR]=Este plugin provê um gerenciador de arquivos ao KDevelop.
Comment[ru]=Это расширение добавляет в KDevelop диспетчер файлов.
Comment[sk]=Tento plugin prináša správcu súborov do KDevelop.
Comment[sl]=Vstavek v KDevelop prinese upravljalnik datotek.
Comment[sv]=Insticksprogrammet ger KDevelop en filhanterare.
Comment[tr]=Bu eklenti KDevelop için bir dosya yönetici sağlar.
Comment[ug]=بۇ قىستۇرما ھۆججەت باشقۇرغۇنى KDevelop نىڭ ئىچىگە ئېلىپ كىرىدۇ
Comment[uk]=За допомогою цього додатка можна отримати доступ до менеджера файлів у KDevelop.
Comment[x-test]=xxThis plugin brings a filemanager to KDevelop.xx
Comment[zh_CN]=此插件对 KDevelop 整合一个文件管理器。
Comment[zh_TW]=此外掛程式讓 KDevelop 可使用檔案管理員。
Name=KDE File Manager Integration
Name[bg]=Интегриране на файлов манипулатор на KDE
Name[bs]=KDe menadžer integracije datoteke
Name[ca]=Integració del gestor de fitxers del KDE
Name[ca@valencia]=Integració del gestor de fitxers del KDE
Name[da]=Integration af KDE filhåndtering
Name[de]=Integration der KDE-Dateiverwaltung
Name[el]=Ενσωμάτωση διαχειριστή αρχείων του KDE
Name[en_GB]=KDE File Manager Integration
Name[es]=Integración del gestor de archivos de KDE
Name[et]=KDE lõimimine failihalduriga
Name[fi]=KDE-tiedostohallintaintegrointi
Name[fr]=Intégration du gestionnaire de fichiers de KDE
Name[gl]=Integración co xestor de ficheiros do KDE
Name[hu]=KDE fájlkezelő integráció
Name[it]=Integrazione gestore di file di KDE
Name[ja]=KDE のファイルマネージャの統合
Name[kk]=KDE файл менеджерімен біріктіру
Name[nb]=Integrasjon med KDE filbehandler
Name[nds]=KDE-Dateiplegerünnerstütten
Name[nl]=KDE Bestandsbeheerder-integratie
Name[pl]=Integracja menadżera plików KDE
Name[pt]=Integração com o Gestor de Ficheiros do KDE
Name[pt_BR]=Integração com o gerenciador de arquivos do KDE
Name[ru]=Интеграция файлового менеджера KDE
Name[sk]=Integrácia správcu súborov KDE
Name[sl]=Vgradnja KDE-jevega upravljalnika datotek
Name[sv]=Integrering med KDE:s filhanterare
Name[tr]=KDE Dosya Yöneticisi Bütünleşmesi
Name[ug]=KDE ھۆججەت باشقۇرغۇنىڭ يۈرۈشلەشتۈرۈلۇشى
Name[uk]=Інтеграція засобу керування файлами KDE
Name[x-test]=xxKDE File Manager Integrationxx
Name[zh_CN]=KDE 文件管理器整合
Name[zh_TW]=KDE 檔案管理員整合
GenericName=File Manager
GenericName[bg]=Файлов манипулатор
GenericName[bs]=Upravljanje datotekama
GenericName[ca]=Gestor de fitxers
GenericName[ca@valencia]=Gestor de fitxers
GenericName[cs]=Správce souborů
GenericName[da]=Filhåndtering
GenericName[de]=Dateiverwaltung
GenericName[el]=Διαχειριστής αρχείων
GenericName[en_GB]=File Manager
GenericName[eo]=Dosieradministrilo
GenericName[es]=Gestor de archivos
GenericName[et]=Failihaldur
GenericName[fi]=Tiedostohallinta
GenericName[fr]=Gestionnaire de fichiers
GenericName[ga]=Bainisteoir Comhad
GenericName[gl]=Xestor de ficheiros
GenericName[hu]=Fájlkezelő
GenericName[it]=Gestore di file
GenericName[ja]=ファイルマネージャ
GenericName[kk]=Файл менеджері
GenericName[lt]=Failų tvarkyklė
GenericName[lv]=Failu pārvaldnieks
GenericName[mr]=फाईल व्यवस्थापक
GenericName[ms]=Pengurus Fail
GenericName[nb]=Filbehandler
GenericName[nds]=Dateipleger
GenericName[nl]=Bestandsbeheerder
GenericName[pa]=ਫਾਇਲ ਮੈਨੇਜਰ
GenericName[pl]=Menadżer plików
GenericName[pt]=Gestor de Ficheiros
GenericName[pt_BR]=Gerenciador de arquivos
GenericName[ro]=Gestionar de fișiere
GenericName[ru]=Файловый менеджер
GenericName[sk]=Správca súborov
GenericName[sl]=Upravljalnik datotek
GenericName[sv]=Filhanterare
GenericName[tr]=Dosya Yönetici
GenericName[ug]=ھۆججەت باشقۇرغۇ
GenericName[uk]=Менеджер файлів
GenericName[x-test]=xxFile Managerxx
GenericName[zh_CN]=文件管理器
GenericName[zh_TW]=檔案管理員
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevfilemanager
X-KDE-PluginInfo-Name=kdevfilemanager
X-KDE-PluginInfo-Author=Alexander Dymo
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
